Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

16x10 - A "Little" Avant Garde

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

16x10 - A "Little" Avant Garde

Post by bunniefuu »

HEIDI:
Previously on Project Runway...

You will be going head-to-head
in a one-hour challenge.

[frustrated grunt]

[crying]: I just don't want
to do it, babe.

I just don't want to.

Where's Tim?

I think it's Claire
that needs to stay.

-[crying] -You'll make beautiful
things without me, okay?

I have faith that

she will succeed.

For your next challenge,

you will be dressing
women on the go.

The winner will receive $25,000.

-[gasping]
-Whoa.

MARGARITA: Claire's draping
a piece that looks

damn near exact

what I made
for JCPenney last week.

MICHAEL: The fact that Claire
isn't playing the game right

really bothers me.

-This is sublime.
-HEIDI: I agree with Zac,

but only on the color.

NINA:
I love a graphic print.

I would want to have
that Dixie cup.

-I'm very confused.
-Big missed opportunity.

The dress and the top
have no connection whatsoever.

-I expect a lot more from you.
-What happened?

I got distracted in the workroom
and just lost my focus.

What was so distracting?

Claire, you are the winner
of this challenge.

TIM:
Who's leaving?

Michael, why are you running
off the stage?

♪ ♪

-[clamoring] -MAN: All right,
quickly. Be careful.

Pick him up quickly.
Follow him.

Don't give him any air.

Stay with him.
Go, go, go, go, go.

I came to play fair, and...

there's no fairness
in this game.

That has never happened before.

That's concerning.

-What happened?
-HEIDI: What is happening?

Like, I want to know
what's going on backstage.

-Is he not happy?
-No, he's not.

He's not happy
with you winning this?

Michael, what's wrong?

-What's wrong?
-I apologize for making a scene.

-No, no, no. What's wrong?
-I sincerely apologize for that.

What's wrong?
I honestly don't know.

All right, so I do believe
in fairness,

and I believe
that this win lacks that.

Well, you're entitled
to your opinion.

It has nothing to do
with the design.

It has to do with what
is actually going on

behind the scenes.

Claire, did you have
a fight with him?

-No.
-I'm gonna go find Michael.

TIM:
If you wanted to,

you could measure the garment

you're wearing in the room.

MARGARITA:
Claire and Shawn told us one day

that they measure their clothes.

Somebody tell us
what is going on.

So, there was a situation

with Margarita's top.
In addition,

she was measuring her own pants,
and so...

CLAIRE:
I literally took a pair

of pants that I had,
measured them to a T,

and then made the exact
same pant that I have.

You rubbed off the pant.

I referenced a pair of pants

-that I had...
-Which is fine.

-That's fine.
-...to compare.

MICHAEL:
She has a retractable ruler

in the apartment
that she goes home

and measures her garments
for proportion, for fit.

-Um...
-How do we know that?

I've seen it,
and we've discussed it.

She has mentioned it to me.

Well, we will look into this.

If this is happening,
it must stop.

Why don't... why don't you
head back out, Michael.

-Thank you. -HEIDI: Why do
you guys all run off the stage?

I wanted to bring Michael back,
'cause I don't think...

-He's back. -Michael, why are
you running off the stage?

-Making an exit.
-Sorry?

Making an exit.

♪ ♪

I do apologize
for my irrational decision.

I couldn't stand here and listen

to a win that I did not feel
was well deserved.

Absolutely, and my point,
Claire, was--

the top that you presented
in your critique with Tim

was exactly like my JCPenney

asymmetrical, keyhole,
peplum... you know.

-CLAIRE: Honestly...
-I mean, you're not

the first one
to invent that, either.

-I... No, that's...
-You know what I mean?

-And I think that...
-Totally not.

I think you guys all

borrow from each other.

I think being here together

in this tight space,
you inspire each other.

So there's nothing wrong
with that.

The only thing
that you're not allowed

to do is go
on the Internet here...

There is no need for Internet
when you've

brought the pieces
that you're ripping off.

CLAIRE:
Oh, my God.

Yeah, but I don't think
you guys' focus

should be on that.

If you focus on what
other people are doing,

it doesn't lead to success.

Here, this was
the most successful print,

and that is that
in the kind of end of the day.

This whole thing
about copying Margarita?

A total nonissue.

But if Claire used
a measuring tape

or other tools
outside the workroom,

that is absolutely
against the rules,

and there will be consequences.

Okay, can we move forward,
everybody?

♪ ♪

Claire, you won this challenge
because of your print

and how you used it.

And you also won $25,000,
so congratulations.

Thank you so much.

You're in.
You can leave the runway.

Thank you.

CLAIRE:
I don't even care

about the win at this point.

What frustrates me to no end

is that people think
that I have been

ripping off my own clothes.

Kenya, Kentaro, Margarita,

you're all in.
You can leave the runway.

-Thank you.
-Thank you.

MARGARITA:
Ugh.

It sickens me.
I mean, it looks really bad

on all of us.
This was just not the way

[bleep] should have gone down.

[mimicking expl*si*n sound]

Michael.

Batani.

One of you will be out.

♪ ♪

Batani...

I'm sorry. You're out.

Okay.

Michael, that means you're in.

You can leave the runway.

♪ ♪

I'm sorry, Batani.

Thank you.

Auf Wiedersehen.

All the best to you.

Thank you all.

ZAC:
Thank you.

SOPHIA:
Well, this is...

an interesting turn of events.

MICHAEL:
I handled it in a poor way,

and I do wholeheartedly
apologize for that.

I never intended for it
to fester.

I did not use the top

-that she was wearing.
-Homegirl,

-how is it exact? -You guys
spec'd the top and drew it.

It was on the table.

-MARGARITA: Yeah.
-I measured... I measured

a tank top, and I drew out
a shape, and I put...

-MARGARITA: With measurements.
-...four measurements on it.

MICHAEL:
Thank you for admitting that.

-I put four measurements down.
-MARGARITA: Right.

AMY: Whoa, whoa, whoa,
hold it. But that means

you got a tape measure at home,
which is explicitly

-against the rules.
-Then they can take it.

-Then take it. -And I think
that's what bothers us

about the fairness.

We cannot have tape measures

or pens or papers
outside of the workroom.

-It's a tank.
-And we're not allowed

to do it, and it's unfair
to the rest of us.

[door closes]

All right, first things first.

Claire.

-Yes?
-Is it true

that you have had
a measuring tape in your room?

I have a measuring tape.

Is it true that you've been
measuring garments in your room?

I have measured a tank top,

and I have measured the crotch
of a pair of pants.

All right.

Claire, we must rescind your win

and send you home.

Okay.

-AYANA: What?
-That's fine.

-That's fine.
-AYANA: Oh, my gosh.

Nope.

-N-No, just...
-Claire, honestly,

-it was never my intention.
-No, it's...

It's-it's... it's fine.

Claire's possession
of the measuring tape

in her hotel room
and the fact that she used it

to measure clothes
that she owns

and to make specifications

is what is
against the rules here.

I'm very...

regretful...

that I even considered the idea

of holding on to something
that I shouldn't have had.

Project Runway has been

something that I wanted
to be a part of since...

I watched it when I was...

you know, in my...

in my early teens.

And...

these are the worst
possible circumstances

to leave this competition,
but...

that's...

how my story's gonna end.

There is no winner
of this challenge,

but Dixie would still like
to put a print into production,

and the print that they have
chosen was created by Brandon.

-Oh... oh, oh, oh, ooh!
-[others clapping]

TIM:
Congratulations.

BRANDON:
Thank you.

And, Batani, guess what--
you're staying.

-Yay, Batani!
-[laughing]

What a day.

All right, so we met

the other day-- casually.

I'm Teresa Bossong with Dixie,

and I wanted to take the
opportunity to congratulate you.

We really loved your print
and thought it would be

a great fit to put

on our Dixie to-go
Project Runway cup.

Thank you so much.
It's an honor.

I'm very excited as well.

I'm so happy, you know?
I thought it was very Dixie.

That's what I'll be
drinking out of

for life now.

♪ ♪

MARGARITA:
I'm just so embarrassed,

and I feel awful, because...

I feel like I started
all this [bleep].

I, like, have the biggest regret
about how I handled it.

I genuinely didn't expect
for Claire to...

be kicked out
of the competition,

and I feel awful.

♪ ♪

Look at the tiny suitcase!

[gasps]
Look how cute this is.

There are so many,
and I love all of them.

Oh, my God, look at this one!

-No, look at this one.
-This is the travel set.

-[laughing]: Oh, my God.
-[laughter]

-Look at all those contestants.
-Aw!

KIDS:
Whoa!

AYANA: I just see
all these fluffy toys

and these cute little

kids, and I'm just like...
[gasps]

Gosh, they're cute.

BRANDON: I've never
made kidswear before,

so this is gonna be

a new experience for me.

Good morning, designers.
I am thrilled

to introduce you
to Kotomi Nanjo,

U.S. marketing director
from Shopkins.

And with her are these fabulous
Shopkins superfans.

-[laughter]
-KIDS: Hi.

Hi, designers. Shopkins Shoppies
are super stylized dolls

and are dressed head-to-toe
in specific themes,

which are always fun, colorful,
cute and a little bit quirky.

Your challenge is to create
an avant-garde look...

-[gasps]
-...that is inspired

by one of these
young people's favorite

Shopkins Shoppies characters.

Each one of these young people
has a different favorite Shoppie

that they're very excited
to tell you about.

You will use the Shoppie
and the young person's story

to inspire
your avant-garde look.

MICHAEL:
Avant-garde is

pushing fashion forward
and being

as weird as you want to be,

so it is completely

up my alley.

Kotomi and our friends

at Shopkins
have an exciting prize

for this challenge.

Shopkins will create
a one-of-a-kind Shoppie

inspired by the winning design.

-[gasping]
-And...

the winner will receive
a $5,000 cash prize.

-Oh, wow.
-Yes. -Whoa... okay.

We're going to pair each of you
with a Shopkins superfan.

Okay.

First, we have Virginia

and Cocolette
paired with Brandon.

Amaya and Jessicake
are paired with Kenya.

[chuckling]

Isabela and Pineapple Lily--
Margarita.

Leah and Rainbow Kate-- Kentaro.

-Violet and Sara Sushi-- Amy.
-Yeah!

Bella and Bubbleisha-- Ayana.

[squeals]

Roxy and Popette-- Michael.

That means that Kayley
and Peppa-Mint

are paired with Batani.

[chuckling]

All right, designers,
you will have 30 minutes

to consult
with your Shopkins superfan.

This is a one-day challenge.

Your 30 minutes to consult
and sketch begins now.

-Yes!
-[quiet chatter]

-Do you want to sit right here?
-Okay.

These chairs are so tiny.

This is gonna be
about Bubbleisha

and you, so... what kind
of dresses do you like?

My favorite things are, like,
bright colors,

and I like her shoes.
Like, they have

-pink bows on the back.
-Bows! Yes, yes, yes.

BATANI:
If I created a new Shopkin doll,

what would you want her to wear?

A sparkly dress.

BATANI:
Sparkly dress.

I have something here.

She's going to open
her new art exhibit

-in the art gallery...
-Mm-hmm.

...and there's going to be
a costume party to celebrate.

-So she's a painter, huh?
-Yeah.

So she's going
to a disco dance party.

[gasps]
Stop. I love it already.

Roxy pulled out a drawing
that she did.

She has a jumpsuit.

She has a disco-ball headband.

This is, like,
the best thing ever.

I was thinking, like,
we could, like,

stain chocolate into the clothes

so it looks like... like
chocolate, like, dripping down.

BRANDON: She wants me
to stain on chocolate

and smush it in the dress
and drip chocolate everywhere

and just make chocolate
and chocolate and chocolate...

KENYA:
You know what would be cool?

How about if it went like this?

-And what's that?
-A jacket.

-That looks weird.
-You're not seeing the vision?

-No, I'm not. No.
-You're not seeing it? [laughs]

These are erasable, too,
so that's

kind of cool
about our pens here.

Pilot FriXion pens are

amazingly dope.

-That's a pen?
-Right. I know, right?

-Anywho, come on, girl.
-Okay. [laughs]

Would you want to see, like,
big poofy sleeves kind of?

Or maybe we could do, like,
medium skirt up to her knees.

-Mm-hmm.
-And pour glitter glue,

and then add more glitter
to the glue.

I really like
that she has her headband.

-It has, like, shrimp and...
-[chuckles]

-I just really like sushi.
-And cucumber, yeah.

AMY: During my collaboration
with Violet,

I'm propelled right back into
playing with my own daughter

when she was six years old.

All right, designers
and Shopkins superfans,

let's head off.

Your time starts now.

KENTARO: How about this one?
Like a beautiful butterfly

caught in the spiderweb.

Designers,
you have five minutes.

Swatchie!

Yeah, let me get two. Two.

Kayley told me
she liked colors.

I want something
with pops of color,

-so I got the blue.
-Two yards of this.

Then I saw the flowers,
and I got the flowers,

and it just started
all coming together.

-Okay.
-All right, designers.

Time is up.

Thank you, Mood.

DESIGNERS:
Thank you.

Have a good night's nap, Swatch.

[humming, sighing]

Yes!

-AMY: Avant-on-your-garde!
-[soft laughter]

KENYA:
What are you doing, Amy?

[chuckling]:
Not sure.

Amy's wheels are always turning.

MARGARITA:
Since the twins left,

this is like
a whole new place to work in.

Everyone is light

and focused and...

-making jokes.
-[laughter]

This is exactly

how it should be all the time.

Hey.

-Hi, Tim.
-How is everyone?

-Having fun. -You're having fun?
All right, well, that's good.

All right, well, I'm here
to check in with you.

Well, all I have to say is
thank goodness Batani is back.

-Color, pattern, avant-garde.
-Thank you.

-Hooray.
-Still here.

I just want to show the judges

that I can make
a comeback and...

I'm here to win.

Coming together
like a butterfly or insect.

and I'm going to have this
in the back

and maybe something
hanging from it.

I just don't want this
to be a distraction,

where our eye doesn't know
what to... where to go.

Is it over here,
or is it down there?

-Use your gut, and get rid
of this thing. -[laughing]

She kept saying,
"Glitter, glitter."

Then I found this fabric,
so I stitched this packing foam

under it so I can sculpt it
into voluminous shapes.

That was a very smart idea.

So, how is Ayana?

-I'm kind of freaking out. Um...
-Okay.

-Talk to me. -The concept
is that it's gonna be,

like, a short dress
with a lot of ruffles.

-Okay. -So, the ruffles
are gonna kind of sh**t out.

My plan is to use bows.
[laughs]

They're gonna be huge.

And then also
I have some of this.

And I also have this.

-Oh, dear.
-Yep.

Part of the direction here
was to

take this point of origin
in a child's land

but make it sophisticated,

-make it fashion.
-Okay. Okay.

And I love the tiers
and ruffles.

I think that is the look.
But your challenge is to

give this the volume
that it needs,

-or else it's just gonna
look wilted. -Okay.

-I mean, I think you've got
a really winning look. -Yay!

-Thank you so much.
-Thank you, Ayana.

How's Michael?

-Hello.
-What's your design idea?

Roxy told me that she wanted
to do a disco party,

so what I built together
with her is a jumpsuit

that is basically a disco ball

kind of like melting
on the body.

-Will this be
the entire garment? -Yeah.

You-you can't hide anything
with a look like this.

-It will be noticed. All right.
-Yeah.

Carry on.

Well, Amy, you've done a lot.

AMY: Initially,
it was just gonna be a coat.

Now I'm thinking
this could be a coatdress

and that this could actually
be attached to this layer.

-Uh-huh. -And then I don't
really need an undergarment.

And then I had a second layer,
and it had

its own collar
that came over that.

Well, it just looks like a
mishmash of two different looks.

If you were to photograph her
just from the hips up,

what a knockout.

What about the hips down,
though?

[laughing]:
What'll we do with that?

Well, it's-it's not so pleasing.

Don't overthink.
Go, go, go, go.

-Brandon.
-Hi, Tim.

Talk to me. This challenge is
difficult for you, isn't it?

Yeah, it is.

Creating something avant-garde,

you want to be out there,
it has to be kind of new,

has to be an odd silhouette,

and so, given the challenge,

I think this is, like,
really important

to rise to this occasion.

It's a little nerve-wracking.

TIM:
I mean, I would be inclined

to look at this
as the internal piece

and expand from it.

Maybe I just do, like,
a bunch of pieces like this

in different lengths,
different layers,

and they all just...
just kind of, like,

-she's just wearing this all
on her shoulder. -Yeah.

-Okay. -All right,
you have a lot of work to do.

-I do.
-I'm gonna let you do it.

-Okay, Tim.
-All right.

-Thank you, Brandon.
-Thank you.

TIM:
All right, everyone.

I am really excited
about what you're doing.

I want you to know
that your models

will be in, in 45 minutes.

You have until


Please use the Brother Sewing

and Embroidery Studio
responsibly.

-And I will see you in the
morning. -Thank you so much.

-Thank you, thank you.
-DESIGNERS: Thank you, Tim.

See you tomorrow.

Oh, my God.

Time is flying.

This is very dangerous.

Don't try this at home, people.

Hi!

[designers and models murmuring]

So maybe I'm going to have you
inside to cover yourself

and kind of drape it.

So I'll guide you that way...

My model for this challenge
is Jazzmine.

She's about nine feet tall.
Has great shoulders.

If I'm gonna sculpt something,
I mean, here's a good model

to sculpt something on.

[singsongy]:
Yeah, yeah, yeah.

You are the perfect model
for this.

[chuckles]

'Cause imagine if it's,
like, in silver sequins,

like, it's gonna be
over-the-top coolness.

I think the look
is gonna be exciting.

At first,
I-I don't see anything,

'cause it's actually
see-through.

Is it, like,
uncomfortably tight?

-Let me know-- on the legs.
-No.

-No? Okay.
-No. Yeah.

MEISHA:
Until you actually

see it on yourself,

you don't know what to expect.

Anything could happen.

-All righty.
-Thank you so much.

-Bye.
-Bye!

This is so damn ugly.

KENTARO: You know,
why don't you just make a skirt?

Like apron.

Don't worry about it,
because just low apron.

MICHAEL: I think it's gotten
to the point where Brandon

is using Kentaro a lot,
and I can tell that

Brandon's running out of ideas.

I fear that he might

be in trouble with this one.

And just hang it from the body.

BRANDON:
I don't know.

-You don't know?
-[bleep] that.

I'm feeling the pressure,
for sure.

KENTARO: All right, everybody,
time to go home.

[designers groaning]

BRANDON:
Yeah, I could be in the bottom.

-KENTARO: Everybody, let's go.
-BRANDON: I mean...

it's a first for me
feeling this way.

[laughter]

It's a scary thing.

HEIDI:
Coming up on Project Runway...

-Designers, is everyone going
to be ready? -Questionable.

-Is your skirt riding up?
-MONIQUE: Yes.

-Let me cut that. MARGARITA: You
can tell that Amy's not happy.

I feel like I shot myself
in the foot.

-♪ ♪
-[horn honking]

MARGARITA [groaning]:
Oh, God. So much to do.

-So much to do, girl.
-So little time.

All right, so in my sleep,

I changed my mind
about this part.

-Hi!
-Good morning, everyone.

-How are you?
-Not good. -Nervous.

-[laughs] -Nervous.
-TIM: Good to not good?

Good to not good.

-Struggling.
-All right, well,

you have an hour
to send your models to

the Avon Beauty Lab
and to our hair studio.

If there were ever
a challenge for which

you need to use
the JCPenney accessory wall

very thoughtfully,
it's this one.

-Okay, thank you, everyone.
-All right. -Thank you, Tim.

And our models will be in
momentarily.

Wait, did he say
when they're coming in?

-Momentarily.
-Momentarily.

Momentarily.

-Hey!
-Hey.

Boy, that was
seriously momentarily.

[laughing]:
How are you?

BRANDON:
You can hang out.

I've got a lot to finish,

but we're gonna get there, okay?

I'm praying I didn't glue it
to the dress form.

Right now, I'm just so nervous

to see Meisha actually
wearing the jumpsuit,

because I know
that if I get the fit wrong,

I think that's something
that I can't fix at this point.

It's a defining moment
for this challenge.

AYANA:
Now enter...

-at your own risk.
-[laughing]

I'm ready

for Liris to get back
into her look.

You are such a trooper, Liris.

I've been in the safe zone

for the duration
of the competition,

and so I want to put the judges

in a position
where they don't have a choice

but to speak to me.
Even if it's to say,

"This is hideous," at least
they have to bring me forward

and I can no longer be
in the safe zone.

But it is most certainly
avant-garde.

♪ ♪

-Oh, how are we doing today?
-How are you?

-I'm good.
-Good.

-I want to do this color
on her lips. -This is a liquid.

It's really intense color
for the lips.

-[camera shutter snaps]
-AYANA: Beautiful. I love it.

-How are you?
-MARGARITA: I just thought,

like, a smoldering eye.

HECTOR:
With the gel pencil,

I can blend just with one color.

MARGARITA:
So beautiful.

[camera shutter clicks]

I want her lids to be

purple, blue, green, pink.

HECTOR: Basically, creating
all this color for shadow.

BATANI:
For her lips, I wanted a pink.

-[camera shutter clicks]
-Thank you.

Hey.

Designers, in ten minutes,
you and your models

and I are going down
to the runway, all right?

-All right. -Yes, sir.
-Is everyone going to be ready?

-Yes.
-Questionable.

All right. Ten minutes.
Thank you.

Ten minutes is not a lot
of minutes.

MARGARITA:
I want more time.

I'm just gonna attempt
this last piece.

I actually like this a lot.

[Liris laughs]

LIRIS:
I wasn't sure what

this was gonna look like,

but I'm actually
loving the look.

She went there.
She's taking

a major risk.

Maybe this will wake up

the judges to her design.

BATANI:
Walk.

-Is your skirt riding up?
-Yes.

BATANI:
Let me cut that.

[sighing]:
All right, well...

MARGARITA: You can tell
that Amy's not happy.

And she admits it. She's like,
"I'm not proud of this."

And I feel bad for Amy
'cause I feel like

she didn't push herself enough,
and I know she has it in her.

-Hi, Tim.
-Designers and models,

we're headed down
to the runway, everyone.

Who's going to lead?
Margarita.

-MARGARITA: Let's do it.
-Off we go.

AMY:
I'm a little heartbroken

that I let myself
kind of get caught up

in the emotions
of this challenge.

So I feel like I shot myself
in the foot.

HEIDI:
Coming up on Project Runway...

Designers, I love
that you went big--

"go big or go home."

-It looks so well made.
-ZAC: I'm sorry.

It's not the most flattering.
I wrote down "laundry day."

It doesn't look intentional
at all.

-Hello.
-Hello. -Hi.

Welcome to the runway.

Batani, I'm very happy
to see you back here.

-Thank you. -As I always say,
one day you're in,

the next day you're out,
and then you're back in.

For this challenge,
Tim and some very special guests

met you on the runway.

You were to create
avant-garde looks

inspired by
the Shopkins Shoppies

and those little consultants.

The winner of today's challenge

will have a one-of-a-kind
Shoppie created that is inspired

by the winning design.

And the winner
will receive $5,000.

All right, let's say hello
to our judges.

First, we have creative director
for Brooks Brothers Women

and fashion designer, Zac Posen.

-Hi, designers.
-Hi, Zac.

And he also has a new
cookbook out, Cooking with Zac.

Creative director
for Marie Claire magazine,

-Nina Garcia.
-Hi, Nina. -Hello, designers.

And model and actress,
Kate Upton.

-Welcome.
-Hi, Kate. -Hi.

We also have Tim Gunn here
for the runway show.

And, as you know,
he is your mentor

and will not be judging
your looks. Okay?

Let's start the show.

♪ ♪

BRANDON:
She looks stunning.

It's avant-garde.
It's out there.

It's got an interesting
silhouette. It's very clean.

There's a lot of line work.

And I feel like it
represents me as a designer.

BATANI:
I love my design.

I love the color.
I love the volume.

She's just strutting
on the runway,

looking good in my design.

I'm feeling good.
I'm feeling excited.

♪ ♪

[gasping]

Diva alert.

KENYA:
Christina looks phenomenal.

She looks so freaking good
in this dress.

I think that my look
definitely represents

who I am as a designer.

[laughing]

AYANA: Liris is such a trooper.
She really strikes me

as being just very elegant,
very classy, very sexy.

But I put her
in this cute outfit

with, like, a bow on her head,
and it just makes me smile

'cause she's carrying herself
so well,

and it's just
a beautiful combination.

♪ ♪

KENTARO:
My dress is beautiful,

genuine, sincere,
like, right away.

So I think I achieved
that part well.

♪ ♪

AMY: She walks out. The garment
looks fabulous on her.

This is my interpretation
of avant-garde,

and even though it's simple,

it looks like
my design character.

♪ ♪

MARGARITA:
It is literally a dream.

She is sparkling.
She is soft.

She feels so glamorous.

It feels really great
to be able to showcase

this work as more
of an art piece.

It's such a good representation
of what I can do.

♪ ♪

MICHAEL:
Watching Meisha walk down

in basically a glittering
disco ball is really exciting.

She's stunning.

There's so much refinement
in my work,

and there's actual
beauty there.

Designers, this was
an amazing runway show today.

Very exciting.

I have to say,
one of the best ever.

In fact, we have
four high scores today

and only two low.

If I call your name,
please step forward.

Kenya.

Kentaro.

Congratulations.
Your scores have

qualified you to move on
to the next round.

-You can leave the runway.
-Thank you.

The six of you have the highest
and the lowest scores.

One of you
will be named the winner,

and one or more of you
will be out.

Ayana, tell us about
your inspiration and your look.

My inspiration came from
my Shopkins superfan, Bella.

We just kind of put
our ideas together.

We focused on fun, and I just
wanted to show that in the look.

I think it's a showstopper.

All of the looks
are so colorful and great,

but this one, you see
how much time you put into it,

and I love the entire look.

I think it's done very well.

I mean, especially in a day.

I absolutely love this look.

I love the imagination.

I love that you went big--
"go big or go home."

I love the bows.
I love the color.

I love the volume.

This is what avant-garde's
all about.

My favorite part of this outfit
is really that oversized bow.

There's something
very sophisticated

but, at the same time,
very childlike.

That was just the icing
on the cake.

-Thank you.
-HEIDI: Michael.

My Shopkins expert, Roxy, said
that she had a concept in mind

which was very disco-themed.

So I came up with the concept
of a disco ball melting

and dragging away.

NINA:
It looks great.

She looks fantastic,
but more important

than everything else--
it looks so well made.

The volume in the exterior--

it just makes it
a little more sci-fi.

I totally got this
liquid-melting quality.

And I love seeing this level
of imagination from you.

This is exciting.
This is fresh. This is new.

And it captures the imagination.

And that's what fashion
at the end of the day--

high fashion-- is really about.

HEIDI:
Brandon.

So, my little girl
had a Cocolette doll.

She was like, "Chocolate,
chocolate, chocolate.

"I just want chocolate.
Can we, like,

drip chocolate on it and, like,
melt chocolate in it?"

So hopefully I don't break
her heart when she sees this,

but brown wasn't really speaking
to me tonight.

I found this, like,
double-faced fabric,

and I knew that I wanted
to place, like, this volume

on the side of, like,
kind of a cuff.

It came together,
but it was a struggle.

I think it's really cool.

I immediately got
the cuff rollup.

I think you have
a really clear aesthetic.

It's very sophisticated.

I don't think this
is gonna be everybody's

-cup of tea that sees this.
-Right.

But I think it's
really great work.

I think you should be
really proud,

and I just want to see more
from you.

I actually cook in an apron
that exact same color,

so I definitely got

the... the character
right away as well.

I thought it was great.
I love this detail up here.

I thought it was beautiful.

Thank you.

HEIDI:
Batani.

So, my Shopkins superfan,

she loved the color blue.

She loved ice cream cones
and flowers.

And I just wanted

to play on volume
and color, and...

yeah, that's what
I got inspired by.

I have to say,
I was not in love with this.

It's kind of like a lot
of scraps sewn together.

But then, when it comes off,
it really looks so unfinished

that it doesn't look
intentional anymore.

There's something, quite
frankly, that's not working.

You know, I-I wrote down
"laundry day."

-[laughs] -And then,
if you turn to the back?

I'm sorry,
the cutout on the back,

it's not the most flattering.

-BATANI: Mm-hmm.
-KATE: I have to agree.

You know,
there's an art to doing

deconstructed construction,

and it's not very polished.

And leaving that black skirt,

it doesn't look
intentional at all.

HEIDI:
Amy.

Uh, one of the things I got

from talking to Violet--
she liked most

that there were
little molded pieces

that would snap
on and off the garment

so that there was a garment,

but then there were little
cool things that went with it.

And that's kind of
what I was going for.

I have to be honest,
I was not the biggest fan

of this look today.

Just because...

of the comparison
to the other designers.

-I see that. Yeah.
-And the other looks

that came down the runway.

I understand that you're
very streamlined as a designer,

but I don't think that means
that you cannot be

an avant-garde designer.

It's really breaking the rules
or breaking the norm.

And that's kind of what
I wanted to see from you.

So this, sadly,
is not my favorite look.

Margarita.

My Shopkins superfan, Isabela,

was already envisioning
an Oscars dress,

and she shares the same love
for sparkles as I do.

I found this beaded fabric,

and I just wanted to organically
come up with the silhouette.

I loved this look.

All the different textures

were really put together in a
very flattering, beautiful way.

-Thank you. -ZAC: You can
feel the sensuality.

You can feel emotion in it.

And that's because you draped it
and you let the fabric speak.

Well done.

NINA:
I love the fact that you took

different fabrics
with different textures

and built this 360 expl*si*n.

-She looks very on point.
-Thank you.

Okay, we've heard
what you had to say.

We're going to take
a closer look at your designs,

have a little chat,
and then I'll call you back

onto the runway.
Thank you.

HEIDI: The winner
of Project Runway will receive

the opportunity to collaborate
with JCPenney

on a limited edition
capsule collection

as part
of the Project Runway line sold

at select JCPenney stores
and online at JCP.com;

a selection of Brother sewing
and embroidery machines,

with a retail value of $40,000;

makeup and beauty products
for a year, courtesy of Avon;

the new 2018 Lexus NX,
coming this fall

with advanced innovation
and safety system standard;

from the Pilot FriXion
Erasable Pen,

the official pen
of Project Runway,

a lifetime supply of pens;

an all-expense-paid luxury trip
to Japan,

including a five-star stay
near Japan's fashion center;

$100,000 to launch their line;

and the winning designer
and model will receive

a fashion spread
in Marie Claire magazine.

-TIM: Hi.
-Hi.

It may be difficult
to scoot over.

[laughter]

We have a lot of volume today.

So, should we start with Liris?

-HEIDI: Yes.
-Wearing Ayana.

Wow.

You are loving this.

-[laughing]
-I can tell.

-Yes. Yes.
-She's like, "Yes."

How cool.

Oh, it's like a pillow.

-[laughing]
-It's so nice.

-It's all, like, really...
-ZAC: Yeah.

It's really padded
and really nice.

ZAC: You got the pillows
and the ruffled sheets.

-Right? -NINA: Oh,
and did you guys notice

-the bow up in the hair?
-HEIDI: Yeah.

-Bows, bows and bows.
-ZAC: It's great.

But it works for this challenge.

And Meisha is wearing Michael.

-ZAC: How cool.
-Yes. -Wow.

-Oh, yes.
-After he explained the whole

disco ball melting,

it gave me even more of an
appreciation for this design.

Because then I could really
see it happening,

especially around the leg area.

-That's great.
-NINA: Amazing. -ZAC: Amazing.

I love this look.

TIM:
Sian is wearing Margarita.

-HEIDI: And I love this.
-Well, this textile she found

is really special.

-Yeah.
-ZAC: Wow. Cool.

-This, she hand...
-NINA: Embroidered?

-Yeah, she put, like, tiny
little pieces. -TIM: Yes.

ZAC: Yeah, just to
pick up the sparkle.

Yeah, to pick it up.

I mean, one day.

It's just exciting to see.

-HEIDI: I love this.
-NINA: It is very nice.

TIM:
And Sanita is wearing Brandon.

-Very cool.
-So interesting.

Can we see the back?

-It's great.
-It's great.

This, which feels
so streamlined,

-and then that-- yum.
-NINA: I love them. Yeah.

NINA:
I love the excess of the straps.

TIM:
And Monique is wearing Batani.

HEIDI:
This, to me, is terrible.

Already we send her away.

Here she is back again,
and then you do that?

-KATE: I like the fabric
she used. -HEIDI: Yeah.

KATE: I like the floral,
I like that blue,

and then it just wasn't done.

TIM:
But she certainly is confident.

-ZAC: Very. -Yeah.
-HEIDI: If this would have

stayed on, I would have
been okay with it.

She should have put that at the
bottom and made an actual skirt.

No, I mean,
we're not here to redesign.

-No, but it's like... No.
-But that's not hard.

TIM:
And Jazzmine is wearing Amy,

who also struggled profoundly.

Yeah, you can tell.

Amy's was really
uninspired, too.

Like, this is what she sent
down the runway,

and it's just boring.

ZAC: Maybe Amy's not a
one-day-challenge kind of gal.

Amy and Batani are just not up
to the same standards here.

For me, it's now refinement time
for Fashion Week.

We got to really start to focus.
We're getting close.

Okay, so we made our decision?

Let's bring them back out.

Designers, one of you
will be named the winner,

and one or more of you
will be out.

Michael, congratulations.

You are the winner
of this challenge.

-Thank you.
-[applause]

HEIDI: And Shopkins will create
a one-of-a-kind Shoppie

inspired by your design.

-Isn't that exciting?
-Yeah. Thank you.

And, on top of it,
you win $5,000.

Thank you.

It really means a lot that you

saw what I wanted to do.

You're in.
You can leave the runway.

Thank you.

MICHAEL:
Winning this challenge

comes as a huge surprise,

because I didn't expect
the judges

to respond to it
in the way that they did.

Oh! Did you win?

-Yes.
-Serious?

-Yeah.
-Oh, my God.

HEIDI:
Ayana, Margarita, Brandon,

you're all in.
You can leave the runway.

Thank you.

Batani.

I'm sorry. You're out.

All right.

-NINA: Bye again.
-HEIDI: Again.

Again, auf Wiedersehen.

Bye.

BATANI:
I actually really liked

my design for this runway,
but, you know, everybody

has their own opinion
about what they like

or what they don't like.

KENYA:
Yes? No?

-I'm going home again.
This time, for real. -Oh.

I don't think I deserve
to go home,

but if they want to send me home

based on their opinion,
that's fine.

You know we love you.

Amy.

I'm sorry.
You're out as well.

Oh.

[sighs]
So it goes.

-It was nice to meet you all.
-Auf Wiedersehen.

-All the best to you.
-Thank you.

AMY:
Especially for this challenge,

I didn't get as brave
as the rest of

the designers in this room.

So I get it.

It was just a surprise.

-I'm going, too.
-AYANA: No.

-What? -She's lying.
-Yeah, both of us.

Two people are going home?

-AMY: That's right.
-Are you serious?

-You're kidding.
-Are you joking, Amy?

KENYA:
They did a double whammy on us.

It's like, in this game,
you just never know.

Nobody's safe.
Nobody is off limits.

You never know what will happen.

Tim, what's happening?

This is a point where this
is like the Olympics

and someone is going to lose--
or two people will--

by mere hairs of a second.

Well, I have to send you
and, Batani, you

to the workroom
to clean up your spaces.

-All right.
-Okay?

It's been a great experience
here at Project Runway.

Meeting wonderful people.

-TIM: Bye.
-Bye, guys.

BATANI:
It's just been surreal, so...

what more can you ask for?

AMY: This experience
has opened up my mind

in a lot of ways,
which is really

what I was hoping for
coming to Project Runway

more than anything else.

So I leave feeling
rejuvenated.

I leave feeling uplifted.

I understand myself again
as a creative person.

So this will be
influential to me

in ways maybe I don't even
understand yet.

♪ ♪

HEIDI:
Next time on Project Runway...

This will be an unconventional
materials challenge.

Go, go, go, go, go.

KENYA:
I'm not built for this.

-Uh-oh.
-[gasps]

Oh, my God.

This is so freaking ill-fitting.

I think it's fly as hell.

Is it just going
to look very messy?

-[bleep]
-It's a tough one, Tim.

I don't like leaving you
like this.

-She looks hot.
-Hot.

It was just moving beautifully.

She could've just been wearing
that and a trash bag,

-and I would've loved it.
-It is so over the top.

-Yeah, I'm not a fan.
-I see a lack of vision.

HEIDI: Visit myLifetime.com
to learn more

about the fashion you've seen
on tonight's show.